==> libvirt_0.4.0.orig.tar.gz: libvirt-0.4.0/python/libvirt-py.h <==
/* Generated */

PyObject * libvirt_virDomainDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainShutdown(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainLookupByUUIDString(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfDefinedNetworks(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfDomains(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetAutostart(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCreateLinux(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetMaxMemory(PyObject *self, PyObject *args);
PyObject * libvirt_virInitialize(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetConnect(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSuspend(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkCreate(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDestroy(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfNetworks(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkDestroy(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetAutostart(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetBridgeName(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetType(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSave(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCreate(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCoreDump(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetMemory(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkSetAutostart(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetMaxMemory(PyObject *self, PyObject *args);
PyObject * libvirt_virResetLastError(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virConnResetLastError(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainResume(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetAutostart(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetHostname(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetCapabilities(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainPinVcpu(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainRestore(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkLookupByUUIDString(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainLookupByID(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkCreateXML(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfDefinedDomains(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainUndefine(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainReboot(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetUUIDString(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetMaxVcpus(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDetachDevice(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainAttachDevice(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetURI(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectOpenReadOnly(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkUndefine(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetConnect(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetOSType(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetMaxVcpus(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetUUIDString(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainMigrate(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectOpen(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetVcpus(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetID(PyObject *self, PyObject *args);

==> libvirt-0.4.4.tar.gz: libvirt-0.4.4/python/libvirt-py.h <==
/* Generated */

PyObject * libvirt_virStoragePoolGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolGetKey(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectClose(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainShutdown(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolSetAutostart(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolCreateXML(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainLookupByUUIDString(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfDefinedNetworks(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfDomains(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolGetConnect(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainFree(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetAutostart(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolLookupByPath(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCreateLinux(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetMaxMemory(PyObject *self, PyObject *args);
PyObject * libvirt_virInitialize(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetConnect(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSuspend(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkCreate(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDestroy(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfNetworks(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolLookupByUUIDString(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkDestroy(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetBridgeName(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetType(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSave(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCreate(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainCoreDump(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetMemory(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkSetAutostart(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetMaxMemory(PyObject *self, PyObject *args);
PyObject * libvirt_virResetLastError(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolFree(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkDefineXML(PyObject *self, PyObject *args);
PyObject * libvirt_virConnResetLastError(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainResume(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetHostname(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetName(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetXMLDesc(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfStoragePools(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetCapabilities(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainRestore(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolGetPath(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkLookupByUUIDString(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainLookupByID(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolFree(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolDelete(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkCreateXML(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolCreateXML(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolRefresh(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfDefinedDomains(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolLookupByKey(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainUndefine(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainReboot(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkLookupByName(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetMaxVcpus(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainDetachDevice(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolNumOfVolumes(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolUndefine(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainAttachDevice(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetURI(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectOpenReadOnly(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkFree(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolDelete(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkUndefine(PyObject *self, PyObject *args);
PyObject * libvirt_virNetworkGetConnect(PyObject *self, PyObject *args);
PyObject * libvirt_virNodeGetFreeMemory(PyObject *self, PyObject *args);
PyObject * libvirt_virStorageVolGetConnect(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolDestroy(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolLookupByVolume(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetOSType(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolBuild(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectGetMaxVcpus(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainMigrate(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectNumOfDefinedStoragePools(PyObject *self, PyObject *args);
PyObject * libvirt_virConnectOpen(PyObject *self, PyObject *args);
PyObject * libvirt_virStoragePoolCreate(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainSetVcpus(PyObject *self, PyObject *args);
PyObject * libvirt_virDomainGetID(PyObject *self, PyObject *args);
